@@ -265,6 +265,7 @@ def generate_instructions(
     logging.log("Checking for resource files...")
     res_dst = os.path.join(output_directory, resources_dirname)
     res_src = os.path.join(spec.base_path, resources_dirname)
+    copy_resources = False
     if os.path.exists(res_src): # only if there is a source directory
         if os.path.exists(res_dst): # does destination already exist?
             if refresh_resources:
@@ -313,7 +314,8 @@ def generate_instructions(
         rubric_table,
         snippet_markup,
         output_file,
-        standalone=standalone
+        standalone=standalone,
+        report_rubric_link_coverage=True
     )
 
     logging.log("...done rendering instructions.")
@@ -697,6 +699,7 @@ def launch_job(
 
         # Close our log file
         if log_file:
+            logging.set_log_target(sys.stdout)
             log_out.close()
 
     # Prevent further tasks from starting
