@@ -598,3 +598,83 @@ window.addEventListener("load", function () {
 
     TOTAL_FLOATABLE_BINS = bin_index;
 });
+
+
+/*-----------------*
+ * Link decoration *
+ *-----------------*/
+
+/* Decorate links to rubric items and snippets */
+window.addEventListener("load", function () {
+    // Find all links that link to rubric items or snippets and add some
+    // decorations to them based on what they link to. For
+    // evaluated goals, we add a goal status marker, while for
+    // unevaluated goals, we add a marker indicating their core/extra
+    // category. For snippet links, we just give them a title.
+    for (let link of document.querySelectorAll("a:link")) {
+        // only look at anchor links
+        let bare_url = (
+            window.location.protocol
+          + "//"
+          + window.location.host
+          + window.location.pathname
+        );
+        let link_href = link.href;
+        let link_hash = link.hash;
+        if (link_href.startsWith(bare_url) && link_hash.length > 0) {
+            let to_id = link_hash.substring(1);
+            let destination = document.getElementById(to_id);
+            if (!destination) {
+                console.warn("Broken # link:", link);
+                continue; // broken link I guess
+            }
+
+            // only process links to goals
+            if (to_id.startsWith("goal:")) {
+                // Add a class
+                link.classList.add("rubric_link");
+
+                // Figure out category based on parent row's class
+                let row = destination.parentNode;
+                let category = "unknown";
+                for (let cls of row.classList) {
+                    if (cls.startsWith("tag-category-")) {
+                        category = cls.substring(13);
+                    }
+                }
+                // Add a category class to the link
+                link.classList.add("category-" + category);
+
+                // Get the status div for the goal
+                let status_div = destination.querySelector(".goal_status");
+                // Add either a category indicator or a status indicator
+                if (status_div.classList.contains("status_unknown")) {
+                    // not yet evaluated, so we'll indicate category
+                    let catind = document.createElement("span");
+                    catind.classList.add("category_indicator");
+                    catind.innerText = category[0].toLocaleUpperCase();
+                    // Insert our category indicator
+                    link.insertBefore(catind, link.firstChild);
+                } else {
+                    // Insert a clone of the status div
+                    link.insertBefore(
+                        status_div.cloneNode(true),
+                        link.firstChild
+                    );
+                }
+
+                // Set the title of the link to indicate the topic of the
+                // goal that it links to
+                let topic_node = destination.querySelector(".goal-topic");
+                let goal_topic = "Goal: " + topic_node.innerText;
+                link.setAttribute("title", goal_topic);
+            }
+
+            // Add titles to snippet links
+            if (to_id.startsWith("snippet:")) {
+                let sid = to_id.substring(8);
+                link.setAttribute("title", "Snippet: " + sid);
+            }
+        }
+    }
+});
